@@ -1,4 +1,4 @@
-/* $Id: config.cpp 12374 2006-07-03 13:21:51Z brunowolff $ */
+/* $Id: config.cpp 21169 2007-10-23 08:39:31Z soliton $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Copyright (C) 2005 by Guillaume Melquiond <guillaume.melquiond@gmail.com>
@@ -27,20 +27,25 @@
 
 #define ERR_CF LOG_STREAM(err, config)
 
-// Note this isn't a real copy. The children are still in both config trees
-// and updating them will affect both trees.
-config::config(const config& cfg)
+config::config() : values(), children(), ordered_children()
+{
+}
+
+config::config(const config& cfg) : values(), children(), ordered_children()
 {
 	append(cfg);
 }
 
+config::config(const std::string& child) : values(), children(), ordered_children()
+{
+	add_child(child);
+}
+
 config::~config()
 {
 	clear();
 }
 
-// Note this isn't a real copy. The children are still in both config trees
-// and updating them will affect both trees.
 config& config::operator=(const config& cfg)
 {
 	if(this == &cfg) {
@@ -54,8 +59,6 @@ config& config::operator=(const config& cfg)
 	return *this;
 }
 
-// Note this isn't a real copy. The children are still in both config trees
-// and updating them will affect both trees.
 void config::append(const config& cfg)
 {
 	for(all_children_iterator i = cfg.ordered_begin(); i != cfg.ordered_end(); ++i) {
@@ -80,7 +83,7 @@ void config::merge_children(const std::string& key)
 		merged_children.append(**i);
 	}
 
-	clear_children(key);
+	detach_children(key);
 	add_child(key,merged_children);
 }
 
@@ -141,7 +144,7 @@ const config* config::child(const std::string& key) const
 
 config& config::add_child(const std::string& key)
 {
-	std::vector<config*>& v = children[key];
+	child_list& v = children[key];
 	v.push_back(new config());
 	ordered_children.push_back(child_pos(children.find(key),v.size()-1));
 	return *v.back();
@@ -149,7 +152,7 @@ config& config::add_child(const std::string& key)
 
 config& config::add_child(const std::string& key, const config& val)
 {
-	std::vector<config*>& v = children[key];
+	child_list& v = children[key];
 	v.push_back(new config(val));
 	ordered_children.push_back(child_pos(children.find(key),v.size()-1));
 	return *v.back();
@@ -197,12 +200,25 @@ private:
 
 }
 
-void config::clear_children(const std::string& key)
+void config::detach_children(const std::string& key)
 {
 	ordered_children.erase(std::remove_if(ordered_children.begin(),ordered_children.end(),remove_ordered(key)),ordered_children.end());
 	children.erase(key);
 }
 
+void config::clear_children(const std::string& key)
+{
+	ordered_children.erase(std::remove_if(ordered_children.begin(),ordered_children.end(),remove_ordered(key)),ordered_children.end());
+
+	child_map::iterator i = children.find(key);
+	if (i != children.end()) {
+		for (child_iterator c = i->second.begin(); c != i->second.end(); c++) {
+			delete *c;
+		}
+		children.erase(i);
+	}
+}
+
 void config::remove_child(const std::string& key, size_t index)
 {
 	//remove from the ordering
@@ -537,9 +553,6 @@ void config::apply_diff(const config& diff)
 // Create a new config tree as a copy of 'this' overridden by 'c'.
 // Nodes are matched up by name and with name by order. Nodes in 'c',
 // but not in 'this' are added at the end in the order they appeared in 'c'.
-// Note that some nodes in the copied tree are still in both 'this' and 'c'.
-// It worked like this before. This is more efficent, but can have surprising
-// effects if a node is changed in one of these config trees.
 config config::merge_with(const config& c) const
 {
 	config n;
@@ -566,6 +579,23 @@ config config::merge_with(const config& c) const
 	return n;
 }
 
+void config::prune() {
+	string_map::iterator val = values.begin();
+	while(val != values.end()) {
+		if(val->second.empty()) {
+			values.erase(val++);
+		} else {
+			++val;
+		}
+	}
+
+	for(child_map::const_iterator list = children.begin(); list != children.end(); ++list) {
+		for(child_list::const_iterator child = list->second.begin(); child != list->second.end(); ++child) {
+			(*child)->prune();
+		}
+	}
+}
+
 void config::reset_translation() const
 {
 	for(string_map::const_iterator val = values.begin(); val != values.end(); ++val) {
