@@ -1,4 +1,4 @@
-/* $Id: config.hpp 13223 2006-08-26 17:44:23Z dirus $ */
+/* $Id: config.hpp 21169 2007-10-23 08:39:31Z soliton $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -36,9 +36,12 @@ class config
 {
 public:
 	//create an empty node.
-	config() {}
+	config();
 
 	config(const config& cfg);
+	
+	// Create a config with an empty child of name 'child'.
+	config(const std::string& child);
 	~config();
 
 	config& operator=(const config& cfg);
