@@ -1,4 +1,4 @@
-/* $Id: game.cpp 16190 2007-03-08 22:22:48Z jhinrichs $ */
+/* $Id: game.cpp 18008 2007-06-02 07:48:47Z sapient $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -1223,7 +1223,7 @@ bool game_controller::play_multiplayer()
 		} else if(res == 0 || res == 1) {
 			std::string host;
 			if(res == 0) {
-				host = preferences::official_network_host();
+				host = preferences::server_list().front().address;
 			}
 
 			mp::start_client(disp(), game_config_, units_data_, host);
