@@ -1,4 +1,4 @@
-/* $Id: image.hpp 7533 2005-07-20 08:22:37Z ott $ */
+/* $Id: image.hpp 12655 2006-07-19 22:12:08Z xan $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -21,8 +21,6 @@
 #include <string>
 #include <vector>
 
-class team;
-
 ///this module manages the cache of images. With an image name, you can get
 ///the surface corresponding to that image.
 //
@@ -49,6 +47,8 @@ namespace image {
 		// Called by each constructor after actual construction to
 		// initialize the index_ field
 		void init_index();
+		void get_tc_info(const std::string& field);
+		void parse_arguments();
 	public:
 		enum type { NONE, FILE, SUB_FILE };
 
@@ -56,8 +56,10 @@ namespace image {
 			value();
 			value(const value &a);
 			value(const char *filename);
+			value(const char *filename, const color_range& new_rgb, const std::vector<Uint32>& swap_rgb);
 			value(const std::string& filename);
-			value(const std::string& filename, const gamemap::location& loc);
+		        value(const std::string& filename, const color_range& new_rgb, const std::vector<Uint32>& swap_rgb);
+			value(const std::string& filename, const gamemap::location& loc, const color_range& new_rgb, const std::vector<Uint32>& swap_rgb);
 
 			bool operator==(const value& a) const;
 			bool operator<(const value& a) const;
@@ -65,17 +67,21 @@ namespace image {
 			type type_;
 			std::string filename_;
 			gamemap::location loc_;
+		        color_range new_color;
+		std::vector<Uint32> swap_colors;
 		};
 
 		// Constructing locators is somewhat slow, accessing image
 		// through locators is fast. The idea is that calling functions
 		// should store locators, and not strings to construct locators
 		// (the second will work, of course, but will be slower)
-		locator();
+	        locator();
 		locator(const locator &a);
 		locator(const char *filename);
+		locator(const char *filename, const color_range& new_rgb, const std::vector<Uint32>& swap_rgb);
 		locator(const std::string& filename);
-		locator(const std::string& filename, const gamemap::location& loc);
+		locator(const std::string& filename, const color_range& new_rgb, const std::vector<Uint32>& swap_rgb);
+		locator(const std::string& filename, const gamemap::location& loc, const color_range& new_rgb = std::vector<Uint32>(), const std::vector<Uint32>& swap_rgb = std::vector<Uint32>());
 
 		locator& operator=(const locator &a);
 		bool operator==(const locator &a) const { return index_ == a.index_; }
@@ -84,6 +90,8 @@ namespace image {
 
 		const std::string &get_filename() const { return val_.filename_; }
 		const gamemap::location& get_loc() const { return val_.loc_ ; }
+		const color_range& get_new_color() const { return val_.new_color ; }
+		const std::vector<Uint32>& get_swap_colors() const { return val_.swap_colors ; }
 		const type get_type() const { return val_.type_; };
 		// const int get_index() const { return index_; };
 
@@ -126,6 +134,8 @@ namespace image {
 
 	typedef std::vector<cache_item<surface> > image_cache;
 	typedef std::vector<cache_item<locator> > locator_cache;
+	typedef std::map<gamemap::TERRAIN, surface> mini_terrain_cache_map;
+	extern mini_terrain_cache_map mini_terrain_cache;
 
 	void flush_cache();
 
@@ -155,6 +165,8 @@ namespace image {
 	///the 'mask' is blitted onto all scaled images.
 	void set_image_mask(const std::string& image_name);
 
+	extern SDL_PixelFormat* pixel_format;
+
 	///sets the pixel format used by the images. Is called every time the
 	///video mode changes. Invalidates all images.
 	void set_pixel_format(SDL_PixelFormat* format);
@@ -163,7 +175,7 @@ namespace image {
 	///scaled images.
 	void set_zoom(int zoom);
 
-	enum TYPE { UNSCALED, SCALED, UNMASKED, GREYED, BRIGHTENED, SEMI_BRIGHTENED };
+	enum TYPE { UNSCALED, SCALED, UNMASKED, GREYED, DARKENED, BRIGHTENED, SEMI_BRIGHTENED };
 
 	enum COLOUR_ADJUSTMENT { ADJUST_COLOUR, NO_ADJUST_COLOUR };
 
@@ -195,10 +207,6 @@ namespace image {
 
 	//returns true if the given image actually exists, without loading it.
 	bool exists(const locator& i_locator);
-
-	///function to create the minimap for a given map
-	///the surface returned must be freed by the user
-	surface getMinimap(int w, int h, const gamemap& map_, const team* tm=NULL);
 }
 
 #endif
