@@ -1,4 +1,4 @@
-/* $Id: intro.cpp 8172 2005-09-06 13:53:14Z ott $ */
+/* $Id: intro.cpp 11940 2006-06-08 10:32:49Z rusty $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -15,19 +15,21 @@
 
 #include "display.hpp"
 #include "events.hpp"
-#include "font.hpp"
 #include "game_config.hpp"
 #include "gettext.hpp"
 #include "image.hpp"
 #include "intro.hpp"
+#include "font.hpp"
 #include "key.hpp"
 #include "log.hpp"
+#include "marked-up_text.hpp"
 #include "sdl_utils.hpp"
 #include "sound.hpp"
 #include "util.hpp"
 #include "video.hpp"
 #include "widgets/button.hpp"
 #include "game_events.hpp"
+#include "language.hpp"
 
 #include <cstdlib>
 #include <sstream>
@@ -35,10 +37,6 @@
 
 #define LOG_NG LOG_STREAM(info, engine)
 
-namespace {
-	const int min_room_at_bottom = 150;
-}
-
 bool show_intro_part(display &disp, const config& part,
 		const std::string& scenario);
 
@@ -86,10 +84,11 @@ bool show_intro_part(display &disp, const config& part,
 
 	//play music if available
 	if(music_file != "") {
-		sound::play_music(music_file);
+		sound::play_music_repeatedly(music_file);
 	}
 
 	CKey key;
+	bool		lang_rtl = current_language_rtl();
 
 	gui::button next_button(video,_("Next") + std::string(">>>"));
 	gui::button skip_button(video,_("Skip"));
@@ -111,50 +110,67 @@ bool show_intro_part(display &disp, const config& part,
 
 	SDL_Rect dstrect;
 
-	if(!background.null()) {
-		dstrect.x = video.getx()/2 - background->w/2;
-		dstrect.y = video.gety()/2 - background->h/2;
-		dstrect.w = background->w;
-		dstrect.h = background->h;
+	if(background.null() || background->w*background->h == 0) {
+		background.assign(SDL_CreateRGBSurface(SDL_SWSURFACE,1,1,32,0xFF0000,0xFF00,0xFF,0xFF000000));
+	}
 
-		if(dstrect.y + dstrect.h > video.gety() - min_room_at_bottom) {
-			dstrect.y = maximum<int>(0,video.gety() - dstrect.h - min_room_at_bottom);
-		}
+	const int source_aspect = (background->w*1000)/background->h;
+	const int dest_aspect = (video.getx()*1000)/video.gety();
 
-		SDL_BlitSurface(background,NULL,video.getSurface(),&dstrect);
+	int xscale = video.getx();
+	int yscale = video.gety();
+
+	if(dest_aspect >= source_aspect) {
+		xscale = (background->w*yscale)/background->h;
+	} else {
+		yscale = (background->h*xscale)/background->w;
+	}
+
+	const int map_w = background->w;
+	const int map_h = background->h;
+
+	background = scale_surface(background,xscale,yscale);
+
+	dstrect.x = video.getx()/2 - background->w/2;
+	dstrect.y = video.gety()/2 - background->h/2;
+	dstrect.w = background->w;
+	dstrect.h = background->h;
+
+	SDL_BlitSurface(background,NULL,video.getSurface(),&dstrect);
 
 #ifdef USE_TINY_GUI
-		textx = 10;
-		int xbuttons = video.getx() - 50;
+	textx = 10;
+	int xbuttons = video.getx() - 50;
 #else
-		int xbuttons;
+	int xbuttons;
 
-		if (background->w > 400) {
-			textx = dstrect.x;
-			xbuttons = dstrect.x+dstrect.w-40;
-		} else {
-			textx = 200;
-			xbuttons = video.getx() - 200 - 40;
-		}
-#endif
-		texty = dstrect.y + dstrect.h + 10;
-
-		next_button.set_location(xbuttons,dstrect.y+dstrect.h+20);
-		skip_button.set_location(xbuttons,dstrect.y+dstrect.h+70);
+	if (background->w > 500) {
+		textx = dstrect.x + 150;
+		xbuttons = dstrect.x+dstrect.w-140;
 	} else {
-		next_button.set_location(video.getx()-200,video.gety()-150);
-		skip_button.set_location(video.getx()-200,video.gety()-100);
+		textx = 200;
+		xbuttons = video.getx() - 200 - 40;
 	}
+#endif
+	texty = dstrect.y + dstrect.h - 200;
+
+	//darken the area for the text and buttons to be drawn on
+	if(show_title == false) {
+		draw_solid_tinted_rectangle(0,texty,video.getx(),video.gety()-texty,0,0,0,0.5,video.getSurface());
+	}
+
+	next_button.set_location(xbuttons,dstrect.y+dstrect.h-70);
+	skip_button.set_location(xbuttons,dstrect.y+dstrect.h-40);
 
 	//draw title if needed
 	if(show_title) {
 		const SDL_Rect area = {0,0,video.getx(),video.gety()};
-		const SDL_Rect scenario_size =
-		      font::draw_text(NULL,area,font::SIZE_XLARGE,font::NORMAL_COLOUR,scenario,0,0);
+		font::draw_text(NULL,area,font::SIZE_XLARGE,font::NORMAL_COLOUR,scenario,0,0);
 		update_rect(font::draw_text(&video,area,font::SIZE_XLARGE,font::NORMAL_COLOUR,scenario,
-					    dstrect.x,dstrect.y - scenario_size.h - 4));
+					    dstrect.x + 20,dstrect.y + 20));
 	}
 
+	events::raise_draw_event();
 	update_whole_screen();
 	disp.flip();
 
@@ -170,8 +186,8 @@ bool show_intro_part(display &disp, const config& part,
 			const std::string& image_name = (**i)["file"];
 			const std::string& delay_str = (**i)["delay"];
 			const int delay = (delay_str == "") ? 0: atoi(delay_str.c_str());
-			const int x = atoi(xloc.c_str());
-			const int y = atoi(yloc.c_str());
+			const int x = (atoi(xloc.c_str())*background->w)/map_w;
+			const int y = (atoi(yloc.c_str())*background->h)/map_h;
 
 			if(x < 0 || x >= background->w || y < 0 || y >= background->h)
 				continue;
@@ -199,7 +215,7 @@ bool show_intro_part(display &disp, const config& part,
 						return false;
 					}
 
-					SDL_Delay(delay/50);
+					disp.delay(delay/50);
 
 					events::pump();
 					events::raise_process_event();
@@ -231,15 +247,17 @@ bool show_intro_part(display &disp, const config& part,
 
 	const SDL_Rect total_size = font::draw_text(NULL, screen_area(), font::SIZE_PLUS,
 			font::NORMAL_COLOUR, story, 0, 0);
-	if (texty + total_size.h > screen_area().h) {
-		texty = screen_area().h > total_size.h + 1 ? screen_area().h - total_size.h - 1 : 0;
+	if (texty + 20 + total_size.h > screen_area().h) {
+		texty = screen_area().h > total_size.h + 1 ? screen_area().h - total_size.h - 21 : 0;
 
 		draw_solid_tinted_rectangle(textx, texty, total_size.w, total_size.h,
 				0, 0, 0, 128, video.getSurface());
 		update_rect(textx, texty, total_size.w, total_size.h);
 	}
 
-	int xpos = textx, ypos = texty;
+	if(lang_rtl)
+		textx += max_width;
+	int xpos = textx, ypos = texty + 20;
 
 	//the maximum position that text can reach before wrapping
 	size_t height = 0;
@@ -256,6 +274,8 @@ bool show_intro_part(display &disp, const config& part,
 			// FIXME: this is broken: it does not take kerning into account.
 			std::string tmp;
 			tmp.append(itor.substr().first, itor.substr().second);
+			if(lang_rtl)
+				xpos -= font::line_width(tmp, font::SIZE_PLUS);
 			const SDL_Rect rect = font::draw_text(&video,
 					screen_area(),font::SIZE_PLUS,
 					font::NORMAL_COLOUR,tmp,xpos,ypos,
@@ -263,7 +283,8 @@ bool show_intro_part(display &disp, const config& part,
 
 			if(rect.h > height)
 				height = rect.h;
-			xpos += rect.w;
+			if(!lang_rtl)
+				xpos += rect.w;
 			update_rect(rect);
 
 			++itor;
@@ -293,7 +314,7 @@ bool show_intro_part(display &disp, const config& part,
 		disp.flip();
 
 		if(!skip || itor == utils::utf8_iterator::end(story))
-			SDL_Delay(20);
+			disp.delay(20);
 	}
 
 	draw_solid_tinted_rectangle(0,0,video.getx()-1,video.gety()-1,0,0,0,1.0,
@@ -326,8 +347,8 @@ void the_end(display &disp)
 
 		SDL_FillRect(video.getSurface(),&area,0);
 
-		SDL_Delay(10);
+		disp.delay(10);
 	}
 
-	SDL_Delay(4000);
+	disp.delay(4000);
 }
