@@ -1,6 +1,6 @@
-/* $Id: log.hpp,v 1.23 2005/05/01 08:57:54 silene Exp $ */
+/* $Id: log.hpp 7645 2005-07-31 18:56:58Z j_daniel $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
                  2004 by Guillaume Melquiond <guillaume.melquiond@gmail.com>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
@@ -42,7 +42,7 @@ public:
 void timestamps(bool);
 
 extern logger err, warn, info;
-extern log_domain general, ai, config, display, engine, network, filesystem;
+extern log_domain general, ai, config, display, engine, network, filesystem, audio;
 
 class scope_logger
 {
