@@ -1,4 +1,4 @@
-/* $Id: mapgen.cpp 7533 2005-07-20 08:22:37Z ott $ */
+/* $Id: mapgen.cpp 11309 2006-05-06 15:21:53Z rusty $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -124,9 +124,9 @@ height_map generate_height_map(size_t width, size_t height,
 		const int radius = rand()%hill_size + 1;
 
 		const int min_x = x1 - radius > 0 ? x1 - radius : 0;
-		const int max_x = x1 + radius < res.size() ? x1 + radius : res.size();
+		const int max_x = x1 + radius < (long)res.size() ? x1 + radius : res.size();
 		const int min_y = y1 - radius > 0 ? y1 - radius : 0;
-		const int max_y = y1 + radius < res.front().size() ? y1 + radius : res.front().size();
+		const int max_y = y1 + radius < (long)res.front().size() ? y1 + radius : res.front().size();
 
 		for(int x2 = min_x; x2 < max_x; ++x2) {
 			for(int y2 = min_y; y2 < max_y; ++y2) {
@@ -222,7 +222,7 @@ typedef gamemap::location location;
 //false will be returned. true is returned if the river is generated successfully.
 bool generate_river_internal(const height_map& heights, terrain_map& terrain, int x, int y, std::vector<location>& river, std::set<location>& seen_locations, int river_uphill)
 {
-	const bool on_map = x >= 0 && y >= 0 && x < heights.size() && y < heights.back().size();
+	const bool on_map = x >= 0 && y >= 0 && x < (long)heights.size() && y < (long)heights.back().size();
 
 	if(on_map && !river.empty() && heights[x][y] > heights[river.back().x][river.back().y] + river_uphill) {
 		return false;
@@ -329,7 +329,7 @@ struct road_path_calculator : cost_calculator
 
 				  //find out how windy roads should be.
 				  windiness_(maximum<int>(1,atoi(cfg["road_windiness"].c_str()))) {}
-	virtual double cost(const location& loc, const double so_far, const bool isDst) const;
+	virtual double cost(const location& src, const location& loc, const double so_far, const bool isDst) const;
 
 	void terrain_changed(const location& loc) { loc_cache_.erase(loc); }
 	mutable int calls;
@@ -341,10 +341,10 @@ private:
 	mutable std::map<char,double> cache_;
 };
 
-double road_path_calculator::cost(const location& loc, const double so_far, const bool isDst) const
+double road_path_calculator::cost(const location& /*src*/, const location& loc, const double /*so_far*/, const bool /*isDst*/) const
 {
 	++calls;
-	if (loc.x < 0 || loc.y < 0 || loc.x >= map_.size() || loc.y >= map_.front().size())
+	if (loc.x < 0 || loc.y < 0 || loc.x >= (long)map_.size() || loc.y >= (long)map_.front().size())
 		return (getNoPathValue());
 
 	const std::map<location,double>::const_iterator val = loc_cache_.find(loc);
@@ -393,7 +393,7 @@ is_valid_terrain::is_valid_terrain(const std::vector<std::vector<gamemap::TERRAI
 
 bool is_valid_terrain::operator()(int x, int y) const
 {
-	if(x < 0 || x >= map_.size() || y < 0 || y >= map_[x].size()) {
+	if(x < 0 || x >= (long)map_.size() || y < 0 || y >= (long)map_[x].size()) {
 		return false;
 	}
 
@@ -474,7 +474,7 @@ gamemap::location place_village(const std::vector<std::vector<gamemap::TERRAIN>
 	gamemap::location best_loc;
 	size_t best_rating = 0;
 	for(std::set<gamemap::location>::const_iterator i = locs.begin(); i != locs.end(); ++i) {
-		if(i->x < 0 || i->y < 0 || i->x >= map.size() || i->y >= map[i->x].size()) {
+		if(i->x < 0 || i->y < 0 || i->x >= (long)map.size() || i->y >= (long)map[i->x].size()) {
 			continue;
 		}
 
@@ -485,7 +485,7 @@ gamemap::location place_village(const std::vector<std::vector<gamemap::TERRAIN>
 			gamemap::location adj[6];
 			get_adjacent_tiles(gamemap::location(i->x,i->y),adj);
 			for(size_t n = 0; n != 6; ++n) {
-				if(adj[n].x < 0 || adj[n].y < 0 || adj[n].x >= map.size() || adj[n].y >= map[adj[n].x].size()) {
+				if(adj[n].x < 0 || adj[n].y < 0 || adj[n].x >= (long)map.size() || adj[n].y >= (long)map[adj[n].x].size()) {
 					continue;
 				}
 
@@ -693,7 +693,7 @@ std::string default_generate_map(size_t width, size_t height, size_t island_size
 
 	std::map<location,std::string> river_names, lake_names;
 
-	const int nlakes = max_lakes > 0 ? (rand()%max_lakes) : 0;
+	const size_t nlakes = max_lakes > 0 ? (rand()%max_lakes) : 0;
 	for(size_t lake = 0; lake != nlakes; ++lake) {
 		for(int tries = 0; tries != 100; ++tries) {
 			const int x = rand()%width;
@@ -911,7 +911,7 @@ std::string default_generate_map(size_t width, size_t height, size_t island_size
 			continue;
 		}
 
-		if (calc.cost(src, 0.0, false) >= 1000.0 || calc.cost(dst, 0.0, true) >= 1000.0) {
+		if (calc.cost(src,src, 0.0, false) >= 1000.0 || calc.cost(src,dst, 0.0, true) >= 1000.0) {
 			continue;
 		}
 
@@ -929,7 +929,7 @@ std::string default_generate_map(size_t width, size_t height, size_t island_size
 			const int x = step->x;
 			const int y = step->y;
 
-			if(x < 0 || y < 0 || x >= width || y >= height)
+			if(x < 0 || y < 0 || x >= (long)width || y >= (long)height)
 				continue;
 
 			calc.terrain_changed(*step);
@@ -1086,7 +1086,7 @@ std::string default_generate_map(size_t width, size_t height, size_t island_size
 
 				const gamemap::location res = place_village(terrain,x,y,2,cfg);
 
-				if(res.x >= width/3 && res.x < (width*2)/3 && res.y >= height/3 && res.y < (height*2)/3) {
+				if(res.x >= (long)width/3 && res.x < (long)(width*2)/3 && res.y >= (long)height/3 && res.y < (long)(height*2)/3) {
 					const std::string str(1,terrain[res.x][res.y]);
 					const config* const child = cfg.find_child("village","terrain",str);
 					if(child != NULL) {
