@@ -1,4 +1,4 @@
-/* $Id: preferences.cpp 18008 2007-06-02 07:48:47Z sapient $ */
+/* $Id: preferences.cpp 21907 2007-11-22 16:56:23Z soliton $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -409,16 +409,6 @@ void set_turn_bell(bool ison)
 	prefs["turn_bell"] = (ison ? "yes" : "no");
 }
 
-const std::string& turn_cmd()
-{
-	return prefs["turn_cmd"];
-}
-
-void set_turn_cmd(const std::string& cmd)
-{
-	prefs["turn_cmd"] = cmd;
-}
-
 bool message_bell()
 {
 	return prefs["message_bell"] != "no";
