@@ -1,4 +1,4 @@
-/* $Id: preferences.hpp 18008 2007-06-02 07:48:47Z sapient $ */
+/* $Id: preferences.hpp 21907 2007-11-22 16:56:23Z soliton $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -114,9 +114,6 @@ namespace preferences {
 	bool message_bell();
 	void set_message_bell(bool ison);
 
-	const std::string& turn_cmd();
-	void set_turn_cmd(const std::string& cmd);
-
 	bool turn_dialog();
 	void set_turn_dialog(bool ison);
 
