@@ -1,4 +1,4 @@
-/* $Id: preprocessor.cpp 12046 2006-06-11 20:42:17Z sapient $ */
+/* $Id: preprocessor.cpp 21904 2007-11-22 16:06:31Z soliton $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Copyright (C) 2005 by Guillaume Melquiond <guillaume.melquiond@gmail.com>
@@ -657,6 +657,8 @@ bool preprocessor_data::get_chunk()
 					LOG_CF << "ignoring reference to '" << newfilename << "'\n";
 				} else
 #endif
+				// Ignore filenames with '..' in them.
+				if (newfilename.find("..") == std::string::npos) 
 				{
 #ifndef USE_ZIPIOS
 					//if the filename begins with a '~', then look
