@@ -1,4 +1,4 @@
-/* $Id: game.cpp 19124 2007-07-26 02:36:01Z soliton $ */
+/* $Id: game.cpp 21177 2007-10-23 09:27:53Z soliton $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -91,7 +91,7 @@ bool game::filter_commands(network::connection player, config& cfg)
 			} else if(observers_can_chat() && (*i)->child("speak") != NULL && (*i)->all_children().size() == 1) {
 				;
 			} else {
-				std::cerr << "removing observer's illegal command\n";
+				LOG_SERVER << "removing observer's illegal command\n";
 				marked.push_back(index - marked.size());
 			}
 
@@ -146,7 +146,7 @@ void game::start_game()
 	//send [observer] tags for all observers that have already joined.
 	//we can do this by re-joining all players that don't have sides, and aren't
 	//the first player (game creator)
-	for(std::vector<network::connection>::const_iterator pl = observers_.begin(); pl != observers_.end(); ++pl) {
+	for(user_vector::const_iterator pl = observers_.begin(); pl != observers_.end(); ++pl) {
 		if(sides_.count(*pl) == 0) {
 			add_player(*pl);
 		}
@@ -247,7 +247,7 @@ void game::update_side_data()
 	for(user_vector::const_iterator player = users.begin(); player != users.end(); ++player) {
 		player_map::const_iterator info = player_info_->find(*player);
 		if (info == player_info_->end()) {
-			std::cerr << "Error: unable to find player info for connection " << *player << "\n";
+			LOG_SERVER << "Error: unable to find player info for connection " << *player << "\n";
 			continue;
 		}
 
@@ -577,13 +577,13 @@ void game::ban_player(network::connection sock)
 
 bool game::process_commands(const config& cfg)
 {
-	//std::cerr << "processing commands: '" << cfg.write() << "'\n";
+	//LOG_SERVER << "processing commands: '" << cfg.write() << "'\n";
 	bool res = false;
 	const config::child_list& cmd = cfg.get_children("command");
 	for(config::child_list::const_iterator i = cmd.begin(); i != cmd.end(); ++i) {
 		if((**i).child("end_turn") != NULL) {
 			res = res || end_turn();
-			//std::cerr << "res: " << (res ? "yes" : "no") << "\n";
+			//LOG_SERVER << "res: " << (res ? "yes" : "no") << "\n";
 		}
 	}
 
@@ -634,8 +634,8 @@ void game::add_player(network::connection player, bool observer)
 		cfg.add_child("start_game");
 		network::queue_data(cfg, player);
 
-		//send observer join of all the observers in the game to player
-		for(std::vector<network::connection>::const_iterator ob = observers_.begin(); ob != observers_.end(); ++ob) {
+		//send observer join of all the observers in the game to players
+		for(user_vector::const_iterator ob = observers_.begin(); ob != observers_.end(); ++ob) {
 			if(*ob != player) {
 				info = player_info_->find(*ob);
 				if(info != player_info_->end()) {
@@ -827,7 +827,7 @@ bool game::player_on_team(const std::string& team, network::connection player) c
 
 void game::send_data_team(const config& data, const std::string& team, network::connection exclude)
 {
-	for(std::vector<network::connection>::const_iterator i = players_.begin(); i != players_.end(); ++i) {
+	for(user_vector::const_iterator i = players_.begin(); i != players_.end(); ++i) {
 		if(*i != exclude && player_on_team(team,*i)) {
 			network::queue_data(data,*i);
 		}
@@ -836,7 +836,7 @@ void game::send_data_team(const config& data, const std::string& team, network::
 
 void game::send_data_observers(const config& data)
 {
-	for(std::vector<network::connection>::const_iterator i = observers_.begin(); i != observers_.end(); ++i) {
+	for(user_vector::const_iterator i = observers_.begin(); i != observers_.end(); ++i) {
 		network::queue_data(data,*i);
 	}
 }
