@@ -1,4 +1,4 @@
-/* $Id: game.hpp 19124 2007-07-26 02:36:01Z soliton $ */
+/* $Id: game.hpp 21177 2007-10-23 09:27:53Z soliton $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -19,7 +19,7 @@
 
 #include "player.hpp"
 
-#include <algorithm>
+//#include <algorithm>
 #include <map>
 #include <set>
 #include <vector>
