@@ -1,4 +1,4 @@
-/* $Id: exploder_utils.cpp 7120 2005-06-04 19:16:06Z ott $ */
+/* $Id: exploder_utils.cpp 12009 2006-06-10 18:59:00Z torangan $ */
 /*
    Copyright (C) 2004 by Philippe Plantier <ayin@anathas.org>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org
@@ -106,11 +106,11 @@ void masked_overwrite_surface(surface dest, surface src, surface mask, int x, in
 
 	dest_shift = dest->w - src_width;
 
-	for(int j = 0; j < src_height; ++j) {
+	for(size_t j = 0; j < src_height; ++j) {
 		src_beg += small_shift_before;
 		mask_beg += small_shift_before;
 
-		for(int i = 0; i < src_width; ++i) {
+		for(size_t i = 0; i < src_width; ++i) {
 			//Assuming here alpha mask is 0xff000000
 			if((*mask_beg & 0x00ffffff) != 0x00ffffff) {
 				*dest_beg = *src_beg;
