@@ -1,4 +1,4 @@
-/* $Id: unit_types.cpp 14022 2006-10-19 19:23:21Z mordante $ */
+/* $Id: unit_types.cpp 16411 2007-03-26 19:35:49Z noyga $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -215,14 +215,14 @@ int attack_type::attack_animation::matches(bool hit,gamemap::location::DIRECTION
 bool attack_type::matches_filter(const config& cfg,bool self) const
 {
 	const std::string& filter_range = cfg["range"];
-	const t_string& filter_name = cfg["name"];
+	const std::string& filter_name = cfg["name"];
 	const std::string& filter_type = cfg["type"];
 	const std::string& filter_special = cfg["special"];
 
 	if(filter_range.empty() == false && filter_range != range())
 			return false;
 
-	if(filter_name.empty() == false && filter_name != name())
+	if(filter_name.empty() == false && filter_name != id())
 		return false;
 
 	if(filter_type.empty() == false && filter_type != type())
@@ -611,9 +611,9 @@ const std::map<gamemap::TERRAIN,int>& unit_movement_type::defense_mods() const
 
 unit_type::unit_type(const unit_type& o)
     : variations_(o.variations_), cfg_(o.cfg_), race_(o.race_),
-      alpha_(o.alpha_), abilities_(o.abilities_),ability_tooltips_(o.ability_tooltips_),
-      advances_to_(o.advances_to_), experience_needed_(o.experience_needed_),
-      alignment_(o.alignment_),
+      abilities_(o.abilities_),ability_tooltips_(o.ability_tooltips_), alpha_(o.alpha_),
+      experience_needed_(o.experience_needed_),
+      alignment_(o.alignment_), advances_to_(o.advances_to_),
       movementType_(o.movementType_), possibleTraits_(o.possibleTraits_),
       genders_(o.genders_), defensive_animations_(o.defensive_animations_),
       teleport_animations_(o.teleport_animations_), extra_animations_(o.extra_animations_),
