@@ -1,6 +1,6 @@
-/* $Id: util.hpp,v 1.25 2005/06/04 19:16:06 ott Exp $ */
+/* $Id: util.hpp 9534 2006-01-08 11:14:47Z boucman $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -40,9 +40,16 @@ inline bool is_odd(T num) {
 template<typename T>
 inline bool is_even(T num) { return !is_odd(num); }
 
-// guarantees portable results for division by 100
-inline int div100(int num) {
-  return num < 0 ? -((-num) / 100) : num / 100;
+// guarantees portable results for division by 100; round towards 0
+inline int div100rounded(int num) {
+	return (num < 0) ? -(((-num) + 49) / 100) : (num + 49) / 100;
+}
+
+// round (base_damage * bonus / divisor) to the closest integer
+// but up or down towards base_damage
+inline int round_damage(int base_damage, int bonus, int divisor) {
+	const int rounding = divisor / 2 - (bonus < divisor ? 0 : 1);
+	return maximum<int>(1, (base_damage * bonus + rounding) / divisor);
 }
 
 struct bad_lexical_cast {};
@@ -73,6 +80,18 @@ To lexical_cast_default(From a, To def=To())
 	}
 }
 
+template<>
+int lexical_cast<int, const std::string&>(const std::string& a);
+
+template<>
+int lexical_cast<int, const char*>(const char* a);
+
+template<>
+int lexical_cast_default<int, const std::string&>(const std::string& a, int def);
+
+template<>
+int lexical_cast_default<int, const char*>(const char* a, int def);
+
 template<typename From>
 std::string str_cast(From a)
 {
