@@ -1,4 +1,4 @@
-/* $Id: progressbar.cpp 7534 2005-07-20 08:56:52Z ott $ */
+/* $Id: progressbar.cpp 11763 2006-06-01 01:25:17Z sapient $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -11,13 +11,14 @@
    See the COPYING file for more details.
 */
 
-#include "../global.hpp"
+#include "global.hpp"
 
-#include "progressbar.hpp"
+#include "widgets/progressbar.hpp"
 
-#include "../font.hpp"
-#include "../util.hpp"
-#include "../video.hpp"
+#include "font.hpp"
+#include "marked-up_text.hpp"
+#include "util.hpp"
+#include "video.hpp"
 
 namespace gui {
 
@@ -47,7 +48,7 @@ void progress_bar::draw_contents()
 		SDL_FillRect(surf,&inner_area,SDL_MapRGB(surf->format,255,255,255));
 
 		inner_area.w = (inner_area.w*progress_)/100;
-		SDL_FillRect(surf,&inner_area,SDL_MapRGB(surf->format,150,0,0));
+		SDL_FillRect(surf,&inner_area,SDL_MapRGB(surf->format,21,53,80));
 
 		const std::string text = text_.empty() ? str_cast(progress_) + "%" :
 		                         text_ + " (" + str_cast(progress_) + "%)";
