@@ -1,4 +1,4 @@
-/* $Id: scrollbar.cpp 7944 2005-08-21 13:11:28Z gruikya $*/
+/* $Id: scrollbar.cpp 9798 2006-01-24 01:17:58Z rusty $*/
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
                  2004 by Guillaume Melquiond <guillaume.melquiond@gmail.com>
@@ -12,11 +12,11 @@
    See the COPYING file for more details.
 */
 
-#include "../global.hpp"
+#include "global.hpp"
 
-#include "scrollbar.hpp"
-#include "../image.hpp"
-#include "../video.hpp"
+#include "widgets/scrollbar.hpp"
+#include "image.hpp"
+#include "video.hpp"
 
 #include <algorithm>
 #include <iostream>
@@ -86,7 +86,7 @@ unsigned scrollbar::get_max_position() const
 
 void scrollbar::set_position(unsigned pos)
 {
-	if (int(pos) > full_height_ - grip_height_)
+	if (pos > full_height_ - grip_height_)
 		pos = full_height_ - grip_height_;
 	if (pos == grip_position_)
 		return;
@@ -98,9 +98,9 @@ void scrollbar::set_position(unsigned pos)
 
 void scrollbar::adjust_position(unsigned pos)
 {
-	if (int(pos) < grip_position_)
+	if (pos < grip_position_)
 		set_position(pos);
-	else if (int(pos) >= grip_position_ + grip_height_)
+	else if (pos >= grip_position_ + grip_height_)
 		set_position(pos - (grip_height_ - 1));
 }
 
@@ -115,7 +115,7 @@ void scrollbar::move_position(int dep)
 
 void scrollbar::set_shown_size(unsigned h)
 {
-	if (int(h) > full_height_)
+	if (h > full_height_)
 		h = full_height_;
 	if (h == grip_height_)
 		return;
@@ -129,6 +129,7 @@ void scrollbar::set_full_size(unsigned h)
 	if (h == full_height_)
 		return;
 	full_height_ = h;
+	downarrow_.enable(grip_position_ < full_height_ - grip_height_);
 	set_shown_size(grip_height_);
 	set_position(grip_position_);
 	set_dirty(true);
@@ -308,7 +309,7 @@ void scrollbar::handle_event(const SDL_Event& event)
 			new_state = on_grip ? ACTIVE : NORMAL;
 		} else if (state_ == DRAGGED && groove.h != grip.h) {
 			int y_dep = e.y - grip.y - mousey_on_grip_;
-			int dep = y_dep * (full_height_ - grip_height_) / (int)(groove.h - grip.h);
+			int dep = y_dep * int(full_height_ - grip_height_) / (int)(groove.h - grip.h);
 			move_position(dep);
 		}
 		break;
