@@ -1,4 +1,4 @@
-/* $Id: textbox.hpp 9852 2006-01-27 22:38:26Z boucman $ */
+/* $Id: textbox.hpp 15250 2007-01-15 22:42:52Z soliton $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -94,7 +94,7 @@ private:
 
 	//make it so that only one textbox object can be receiving
 	//events at a time.
-	bool requires_event_focus() const { return editable_; }
+	bool requires_event_focus(const SDL_Event *event=NULL) const;
 
 	bool show_scrollbar() const;
 };
